@@ -4,6 +4,7 @@ Based off spec: https://github.com/Society-for-Internet-Blaseball-Research/blase
 """
 import requests
 import requests_cache
+from blaseball_mike.session import session, check_network_response
 
 
 BASE_URL = 'https://www.blaseball.com/database'
@@ -13,7 +14,7 @@ BASE_GITHUB = 'https://raw.githubusercontent.com/xSke/blaseball-site-files/main/
 def get_global_events():
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/globalEvents')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_all_teams():
@@ -22,7 +23,7 @@ def get_all_teams():
     """
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/allTeams')
-    return {t['id']: t for t in res.json()}
+    return {t['id']: t for t in check_network_response(res)}
 
 
 def get_all_divisions():
@@ -31,31 +32,31 @@ def get_all_divisions():
     """
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/allDivisions')
-    return {d['id']: d for d in res.json()}
+    return {d['id']: d for d in check_network_response(res)}
 
 
 def get_league(id_='d8545021-e9fc-48a3-af74-48685950a183'):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/league?id={id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_subleague(id_):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/subleague?id={id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_division(id_):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/division?id={id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_team(id_):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/team?id={id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_player(id_):
@@ -69,7 +70,7 @@ def get_player(id_):
         id_ = ','.join(id_)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/players?ids={id_}')
-    return {p['id']: p for p in res.json()}
+    return {p['id']: p for p in check_network_response(res)}
 
 
 def get_games(season, day):
@@ -79,7 +80,7 @@ def get_games(season, day):
     """
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/games?season={season - 1}&day={day - 1}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_tournament(tournament, day):
@@ -89,19 +90,19 @@ def get_tournament(tournament, day):
     """
     s = requests_cache.CachedSession(backend="memory", expire_after=5)
     res = s.get(f'{BASE_URL}/games?tournament={tournament}&day={day - 1}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_game_by_id(id_):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/gameById/{id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_offseason_election_details():
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/offseasonSetup')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_offseason_recap(season):
@@ -110,7 +111,7 @@ def get_offseason_recap(season):
     """
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/offseasonRecap?season={season - 1}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_offseason_bonus_results(id_):
@@ -121,7 +122,7 @@ def get_offseason_bonus_results(id_):
         id_ = ','.join(id_)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/bonusResults?ids={id_}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_offseason_decree_results(id_):
@@ -132,7 +133,7 @@ def get_offseason_decree_results(id_):
         id_ = ','.join(id_)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/decreeResults?ids={id_}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_offseason_event_results(id_):
@@ -140,7 +141,7 @@ def get_offseason_event_results(id_):
         id_ = ','.join(id_)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/eventResults?ids={id_}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_playoff_details(season):
@@ -149,13 +150,13 @@ def get_playoff_details(season):
     """
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/playoffs?number={season - 1}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_playoff_round(id_):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/playoffRound?id={id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_playoff_matchups(id_):
@@ -166,13 +167,13 @@ def get_playoff_matchups(id_):
         id_ = ','.join(id_)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/playoffMatchups?ids={id_}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_standings(id_):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/standings?id={id_}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_season(season_number):
@@ -181,13 +182,13 @@ def get_season(season_number):
     """
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/season?number={season_number - 1}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_tiebreakers(id):
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/tiebreakers?id={id}')
-    return {g['id']: g for g in res.json()}
+    return {g['id']: g for g in check_network_response(res)}
 
 
 def get_game_statsheets(ids):
@@ -195,7 +196,7 @@ def get_game_statsheets(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/gameStatsheets?ids={ids}')
-    return {s['id']: s for s in res.json()}
+    return {s['id']: s for s in check_network_response(res)}
 
 
 def get_player_statsheets(ids):
@@ -203,7 +204,7 @@ def get_player_statsheets(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/playerSeasonStats?ids={ids}')
-    return {s['id']: s for s in res.json()}
+    return {s['id']: s for s in check_network_response(res)}
 
 
 def get_season_statsheets(ids):
@@ -211,7 +212,7 @@ def get_season_statsheets(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/seasonStatsheets?ids={ids}')
-    return {s['id']: s for s in res.json()}
+    return {s['id']: s for s in check_network_response(res)}
 
 
 def get_team_statsheets(ids):
@@ -219,25 +220,25 @@ def get_team_statsheets(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/teamSeasonStats?ids={ids}')
-    return {s['id']: s for s in res.json()}
+    return {s['id']: s for s in check_network_response(res)}
 
 
 def get_idols():
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get('https://www.blaseball.com/api/getIdols')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_tributes():
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get('https://www.blaseball.com/api/getTribute')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_simulation_data():
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/simulationData')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_attributes(ids):
@@ -245,7 +246,7 @@ def get_attributes(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/mods?ids={ids}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_items(ids):
@@ -253,13 +254,13 @@ def get_items(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/items?ids={ids}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_weather():
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_GITHUB}/weather.json')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_blood(ids):
@@ -267,7 +268,7 @@ def get_blood(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/blood?ids={ids}')
-    return res.json()
+    return check_network_response(res)
 
 
 def get_coffee(ids):
@@ -275,4 +276,4 @@ def get_coffee(ids):
         ids = ','.join(ids)
     s = requests_cache.CachedSession(backend="memory",expire_after=5)
     res = s.get(f'{BASE_URL}/coffee?ids={ids}')
-    return res.json()
+    return check_network_response(res)
